from django.conf.urls import include, url
from django.views.generic.base import TemplateView

try:
    from registration import views  # debian
except ModuleNotFoundError:
    from django_registration import views  # pip


urlpatterns = [
    url(r'^accounts/activate/complete/$',
        TemplateView.as_view(
            template_name='registration/activation_complete.html'
        ),
        name='registration_activation_complete'),
    # Activation keys get matched by \w+ instead of the more specific
    # [a-fA-F0-9]{40} because a bad activation key should still get to
    # the view; that way it can return a sensible "invalid key"
    # message instead of a confusing 404.
    url(r'^accounts/activate/(?P<activation_key>\w+)/$',
        views.ActivationView.as_view(),
        name='registration_activate'),
    url(r'^accounts/register/$',
        views.RegistrationView.as_view(),
        name='registration_register'),
    url(r'^accounts/register/complete/$',
        TemplateView.as_view(
            template_name='registration/registration_complete.html'
        ),
        name='registration_complete'),
    url(r'^accounts/register/closed/$',
        TemplateView.as_view(
            template_name='registration/registration_closed.html'
        ),
        name='registration_disallowed'),
    url("^accounts/", include('django.contrib.auth.urls')),
]